==> zoomapi-2.0.x-dev.tar.gz: zoomapi/tests/src/Functional/ApiRequestTest.php <==
<?php

namespace Drupal\Tests\zoomapi\Functional;

use Drupal\key\Entity\Key;
use Drupal\Tests\BrowserTestBase;
use GuzzleHttp\Exception\RequestException;

/**
 * API request tests.
 *
 * @group zoomapi
 */
class ApiRequestTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['zoomapi', 'key'];

  /**
   * A key entity to use for testing.
   *
   * @var \Drupal\key\KeyInterface
   */
  protected $testKey;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // Create Key module keys.
    // Api Key.
    $this->createTestKey(
      'test_zoomapi_key',
      'authentication',
      'config'
    );

    // API Secret.
    $this->createTestKey(
      'test_zoomapi_secret',
      'authentication',
      'config'
    );

    // Save Zoom API config.
    $this->config('zoomapi.settings')
      ->set('base_uri', 'https://api.zoom.us/v2')
      ->set('api_key', 'test_zoomapi_key')
      ->set('api_secret', 'test_zoomapi_secret')
      ->save();
  }

  /**
   * Try to perform an API call, expecting a failure.
   */
  public function testZoomApiConnection() {
    // Post to the webhook controller.
    $client = \Drupal::service('zoomapi.client');
    try {
      $client->request('GET', '/users');
    }
    catch (RequestException $exception) {
      // We are expecting failure.
      $message = $exception->getMessage();
      $this->assertStringContainsString('401 Unauthorized', $message, '401 Unauthorized was returned.');
      $this->assertStringContainsString('Client error', $message, 'Asserting client error exists.');
    }
  }

  /**
   * Make a key for testing operations that require a key.
   */
  protected function createTestKey($id, $type = NULL, $provider = NULL) {
    $keyArgs = [
      'id' => $id,
      'label' => "Zoom API Webhook Test Key ($id)",
    ];
    if ($type != NULL) {
      $keyArgs['key_type'] = $type;
    }
    if ($provider != NULL) {
      $keyArgs['key_provider'] = $provider;
    }
    $this->testKey = Key::create($keyArgs);
    $this->testKey->setKeyValue('taco');
    $this->testKey->save();
    return $this->testKey;
  }

}

==> zoomapi-3.0.x-dev.tar.gz: zoomapi/tests/src/Functional/ApiRequestTest.php <==
<?php

namespace Drupal\Tests\zoomapi\Functional;

use Drupal\key\Entity\Key;
use Drupal\Tests\BrowserTestBase;
use GuzzleHttp\Exception\RequestException;

/**
 * API request tests.
 *
 * @group zoomapi
 */
class ApiRequestTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['zoomapi', 'apitools', 'key'];

  /**
   * A key entity to use for testing.
   *
   * @var \Drupal\key\KeyInterface
   */
  protected $testKey;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // API Secret.
    $this->createTestKey(
      'test_zoomapi_secret',
      'authentication',
      'config'
    );

    // Save Zoom API config.
    $this->config('apitools.client.zoomapi')
      ->set('account_id', 'taco')
      ->set('client_id', 'burrito')
      ->set('client_secret', 'test_zoomapi_secret')
      ->save();
  }

  /**
   * Try to perform an API call, expecting a failure.
   */
  public function testZoomApiConnection() {
    // Post to the webhook controller.
    $client = \Drupal::service('zoomapi.client');
    try {
      $client->get('users');
    }
    catch (RequestException $exception) {
      // We are expecting failure.
      $message = $exception->getMessage();
      $this->assertStringContainsString('400 Bad Request', $message, '400 Bad Request was returned.');
      $this->assertStringContainsString('Invalid client_id or client_secret', $message, 'Asserting client error exists.');
    }
  }

  /**
   * Make a key for testing operations that require a key.
   */
  protected function createTestKey($id, $type = NULL, $provider = NULL) {
    $keyArgs = [
      'id' => $id,
      'label' => "Zoom API Webhook Test Key ($id)",
    ];
    if ($type != NULL) {
      $keyArgs['key_type'] = $type;
    }
    if ($provider != NULL) {
      $keyArgs['key_provider'] = $provider;
    }
    $this->testKey = Key::create($keyArgs);
    $this->testKey->setKeyValue('taco');
    $this->testKey->save();
    return $this->testKey;
  }

}
